@@ -69,8 +69,6 @@ Control::initialize() {
   m_core->download_store()->enable(rpc::call_command_value("session.use_lock"));
   m_core->set_hashing_view(*m_viewManager->find_throw("hashing"));
 
-  m_dhtManager->set_port(torrent::connection_manager()->listen_port());
-
   m_ui->init(this);
 
   if(!display::Canvas::daemon())
@@ -114,7 +112,7 @@ Control::is_shutdown_completed() {
 
   // TODO: We keep http requests in the queue for a while after, so improve this check to ignore
   // those.
-  if (torrent::net_thread::http_stack()->active() != 0 || !core()->http_queue()->empty())
+  if (torrent::net_thread::http_stack()->size() != 0 || !core()->http_queue()->empty())
     return false;
 
   return torrent::is_inactive();
