@@ -6,7 +6,6 @@
 #include <cstdio>
 #include <sstream>
 #include <iomanip>
-#include <rak/socket_address.h>
 #include <torrent/exceptions.h>
 #include <torrent/connection_manager.h>
 #include <torrent/rate.h>
@@ -17,6 +16,8 @@
 #include <torrent/data/file_manager.h>
 #include <torrent/download/resource_manager.h>
 #include <torrent/net/http_stack.h>
+#include <torrent/net/network_config.h>
+#include <torrent/net/socket_address.h>
 #include <torrent/peer/client_info.h>
 
 #include "control.h"
@@ -29,7 +30,7 @@
 namespace display {
 
 char*
-print_string(char* first, char* last, char* str) {
+print_string(char* first, char* last, const char* str) {
   if (first == last)
     return first;
 
@@ -78,17 +79,9 @@ print_ddmmyyyy(char* first, char* last, time_t t) {
   return print_buffer(first, last, "%02u/%02u/%04u", u->tm_mday, (u->tm_mon + 1), (1900 + u->tm_year));
 }
 
-char*
-print_address(char* first, char* last, const rak::socket_address* sa) {
-  if (!sa->address_c_str(first, last - first))
-    return first;
-
-  return std::find(first, last, '\0');
-}
-
 inline char*
 print_address(char* first, char* last, const sockaddr* sa) {
-  return print_address(first, last, rak::socket_address::cast_from(sa));
+  return print_string(first, last, torrent::sa_addr_str(sa).c_str());
 }
 
 char*
@@ -382,20 +375,24 @@ print_status_info(char* first, char* last) {
 
   first = print_buffer(first, last, " KB]");
 
-  first = print_buffer(first, last, " [Port: %i]", (unsigned int)torrent::connection_manager()->listen_port());
+  first = print_buffer(first, last, " [Port: %i]", (unsigned int)torrent::config::network_config()->listen_port());
 
-  if (!rak::socket_address::cast_from(torrent::connection_manager()->local_address())->is_address_any()) {
+  auto local_address = torrent::config::network_config()->local_address_best_match();
+
+  if (!torrent::sa_is_any(local_address.get())) {
     first = print_buffer(first, last, " [Local ");
-    first = print_address(first, last, torrent::connection_manager()->local_address());
+    first = print_address(first, last, local_address.get());
     first = print_buffer(first, last, "]");
   }
 
   if (first > last)
     throw torrent::internal_error("print_status_info(...) wrote past end of the buffer.");
 
-  if (!rak::socket_address::cast_from(torrent::connection_manager()->bind_address())->is_address_any()) {
+  auto bind_address = torrent::config::network_config()->bind_address_best_match();
+
+  if (!torrent::sa_is_any(bind_address.get())) {
     first = print_buffer(first, last, " [Bind ");
-    first = print_address(first, last, torrent::connection_manager()->bind_address());
+    first = print_address(first, last, bind_address.get());
     first = print_buffer(first, last, "]");
   }
 
@@ -413,8 +410,8 @@ print_status_extra(char* first, char* last) {
                        torrent::resource_manager()->max_download_unchoked());
 
   first = print_buffer(first, last, " [H %u/%u]",
-                       torrent::net_thread::http_stack()->active(),
-                       torrent::net_thread::http_stack()->max_active());
+                       torrent::net_thread::http_stack()->size(),
+                       torrent::net_thread::http_stack()->max_total_connections());
 
   first = print_buffer(first, last, " [S %i/%i/%i]",
                        torrent::total_handshakes(),
