@@ -7,6 +7,7 @@
 #include <time.h>
 #include <rak/string_manip.h>
 #include <torrent/exceptions.h>
+#include <torrent/utils/chrono.h>
 
 #include "rpc/command_scheduler_item.h"
 #include "rpc/parse_commands.h"
@@ -14,7 +15,8 @@
 namespace rpc {
 
 CommandScheduler::~CommandScheduler() {
-  std::for_each(begin(), end(), [](CommandSchedulerItem* item) { delete item; });
+  for (auto item : *this)
+    delete item;
 }
 
 CommandScheduler::iterator
