@@ -1,13 +1,13 @@
 #include "config.h"
 
 #include <cassert>
-#include <rak/error_number.h>
-#include <rak/socket_address.h>
 #include <sys/un.h>
 #include <torrent/connection_manager.h>
 #include <torrent/poll.h>
 #include <torrent/torrent.h>
 #include <torrent/exceptions.h>
+#include <torrent/net/fd.h>
+#include <torrent/net/socket_address.h>
 
 #include "control.h"
 #include "globals.h"
@@ -41,7 +41,7 @@ void
 SCgi::open_port(void* sa, unsigned int length, bool dontRoute) {
   if (!get_fd().open_stream() ||
       (dontRoute && !get_fd().set_dont_route(true)))
-    throw torrent::resource_error("Could not open socket for listening: " + std::string(rak::error_number::current().c_str()));
+    throw torrent::resource_error("Could not open socket for listening: " + std::string(std::strerror(errno)));
 
   open(sa, length);
 }
@@ -51,8 +51,8 @@ SCgi::open_named(const std::string& filename) {
   if (filename.empty() || filename.size() > 4096)
     throw torrent::resource_error("Invalid filename length.");
 
-  char buffer[sizeof(sockaddr_un) + filename.size()];
-  sockaddr_un* sa = reinterpret_cast<sockaddr_un*>(buffer);
+  auto buffer = std::make_unique<char[]>(sizeof(sockaddr_un) + filename.size());
+  sockaddr_un* sa = reinterpret_cast<sockaddr_un*>(buffer.get());
 
 #ifdef __sun__
   sa->sun_family = AF_UNIX;
@@ -74,9 +74,9 @@ SCgi::open(void* sa, unsigned int length) {
   try {
     if (!get_fd().set_nonblock() ||
         !get_fd().set_reuse_address(true) ||
-        !get_fd().bind(*reinterpret_cast<rak::socket_address*>(sa), length) ||
+        !get_fd().bind_sa(reinterpret_cast<sockaddr*>(sa), length) ||
         !get_fd().listen(max_tasks))
-      throw torrent::resource_error("Could not prepare socket for listening: " + std::string(rak::error_number::current().c_str()));
+      throw torrent::resource_error("Could not prepare socket for listening: " + std::string(std::strerror(errno)));
 
     torrent::connection_manager()->inc_socket_count();
 
@@ -108,18 +108,24 @@ SCgi::deactivate() {
 
 void
 SCgi::event_read() {
-  rak::socket_address sa;
-  utils::SocketFd fd;
+  while (true) {
+    int fd = torrent::fd_accept(get_fd().get_fd());
+
+    if (fd == -1) {
+      if (errno == EAGAIN || errno == EWOULDBLOCK)
+        break;
+
+      throw torrent::resource_error("Listener port accept() failed: " + std::string(std::strerror(errno)));
+    }
 
-  while ((fd = get_fd().accept(&sa)).is_valid()) {
     SCgiTask* task = std::find_if(m_task, m_task + max_tasks, std::mem_fn(&SCgiTask::is_available));
 
     if (task == m_task + max_tasks) {
-      fd.close();
+      torrent::fd_close(fd);
       continue;
     }
 
-    task->open(this, fd.get_fd());
+    task->open(this, fd);
   }
 }
 
